About
=====

|Join the chat at https://gitter.im/radio-astro-tools/spectral-cube|

This package aims to facilitate the reading, writing, manipulation, and
analysis of spectral data cubes. More information is available in the
documentation, avaliable `online at
readthedocs.org <http://spectral-cube.rtfd.org>`__.

.. figure:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
   :alt: Powered by Astropy Badge

   Powered by Astropy Badge

Credits
=======

This package is developed by:

-  Eric Koch (`@e-koch <https://github.com/e-koch>`__)
-  Adam Ginsburg (`@keflavich <http://github.com/keflavich>`__)
-  Thomas Robitaille (`@astrofrog <http://github.com/astrofrog>`__)
-  Erik Rosolowsky (`@low-sky <http://github.com/low-sky>`__)

Original development included substantial contributions from:
-  Adam Leroy (`@akleroy <http://github.com/akleroy>`__)
-  Chris Beaumont (`@ChrisBeaumont <http://github.com/ChrisBeaumont>`__)

Build and coverage status
=========================

|Coverage Status| |DOI|

.. |Join the chat at https://gitter.im/radio-astro-tools/spectral-cube| image:: https://badges.gitter.im/Join%20Chat.svg
   :target: https://gitter.im/radio-astro-tools/spectral-cube?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
.. |Coverage Status| image:: https://coveralls.io/repos/radio-astro-tools/spectral-cube/badge.svg?branch=master
   :target: https://coveralls.io/r/radio-astro-tools/spectral-cube?branch=master
.. |DOI| image:: https://zenodo.org/badge/doi/10.5281/zenodo.11485.svg
   :target: http://dx.doi.org/10.5281/zenodo.11485
